CREATE TABLE CMS_USERS (
	USER_ID VARCHAR(36)  NOT NULL,
	USER_NAME VARCHAR(64)  NOT NULL,
	USER_PASSWORD VARCHAR(32)  NOT NULL,
	USER_DESCRIPTION VARCHAR(255) NOT NULL,
	USER_FIRSTNAME VARCHAR(50) NOT NULL,
	USER_LASTNAME VARCHAR(50) NOT NULL,
	USER_EMAIL VARCHAR(100) NOT NULL,
	USER_LASTLOGIN FIXED(20,0) NOT NULL,
	USER_FLAGS INTEGER NOT NULL,
	USER_INFO LONG BYTE,
	USER_ADDRESS VARCHAR(100) NOT NULL,
	USER_TYPE INTEGER NOT NULL,
	PRIMARY KEY	(USER_ID)
);
CREATE UNIQUE INDEX iCMS_USERS ON CMS_USERS(USER_NAME);
CREATE TABLE CMS_GROUPS (
	GROUP_ID VARCHAR(36)  NOT NULL,
	PARENT_GROUP_ID VARCHAR(36)  NOT NULL,
	GROUP_NAME VARCHAR(64)  NOT NULL,
	GROUP_DESCRIPTION VARCHAR(255) NOT NULL,
	GROUP_FLAGS INTEGER NOT NULL,
	PRIMARY KEY (GROUP_ID)
);
CREATE UNIQUE INDEX iCMS_GROUPS ON CMS_GROUPS(GROUP_NAME);
CREATE INDEX CMS_GROUPS_01_IDX 
	ON CMS_GROUPS (PARENT_GROUP_ID);
CREATE TABLE CMS_GROUPUSERS (
	GROUP_ID VARCHAR(36)  NOT NULL,
	USER_ID VARCHAR(36)  NOT NULL,
	GROUPUSER_FLAGS INT NOT NULL
);
CREATE INDEX CMS_GROUPUSERS_01_IDX 
	ON CMS_GROUPUSERS (GROUP_ID);
CREATE INDEX CMS_GROUPUSERS_02_IDX 
	ON CMS_GROUPUSERS (USER_ID);
CREATE TABLE CMS_PROJECTS (
	PROJECT_ID INTEGER NOT NULL,
	PROJECT_NAME VARCHAR(64)  NOT NULL,
	PROJECT_DESCRIPTION VARCHAR(255) NOT NULL,
	PROJECT_FLAGS INTEGER NOT NULL,
	PROJECT_TYPE INTEGER NOT NULL,
	USER_ID VARCHAR(36)  NOT NULL,
	GROUP_ID VARCHAR(36)  NOT NULL, 
	MANAGERGROUP_ID VARCHAR(36)  NOT NULL,
	TASK_ID INTEGER NOT NULL,
	DATE_CREATED FIXED(20,0) NOT NULL,
	PRIMARY KEY (PROJECT_ID)
);
CREATE UNIQUE INDEX iCMS_PROJECTS ON CMS_PROJECTS(PROJECT_NAME,DATE_CREATED);
CREATE INDEX CMS_PROJECTS_01_IDX
	ON CMS_PROJECTS (PROJECT_FLAGS);
CREATE INDEX CMS_PROJECTS_02_IDX
	ON CMS_PROJECTS (GROUP_ID);
CREATE INDEX CMS_PROJECTS_03_IDX
	ON CMS_PROJECTS (MANAGERGROUP_ID);
CREATE INDEX CMS_PROJECTS_04_IDX
	ON CMS_PROJECTS (USER_ID);
CREATE INDEX CMS_PROJECTS_05_IDX
	ON CMS_PROJECTS (TASK_ID);
CREATE TABLE CMS_BACKUP_PROJECTS (
	PROJECT_ID INTEGER NOT NULL,
	PROJECT_NAME VARCHAR(64)  NOT NULL,
	PROJECT_DESCRIPTION VARCHAR(255) NOT NULL,
	PROJECT_TYPE INTEGER NOT NULL,
	USER_ID VARCHAR(36)  NOT NULL,
	GROUP_ID VARCHAR(36)  NOT NULL,
	MANAGERGROUP_ID VARCHAR(36)  NOT NULL,
	TASK_ID INTEGER NOT NULL,
	DATE_CREATED FIXED(20,0) NOT NULL,	
	PUBLISH_TAG INTEGER NOT NULL,
	PROJECT_PUBLISHDATE TIMESTAMP,
	PROJECT_PUBLISHED_BY VARCHAR(36)  NOT NULL,
	PROJECT_PUBLISHED_BY_NAME VARCHAR(167),
	USER_NAME VARCHAR(167),
	GROUP_NAME VARCHAR(64) ,
	MANAGERGROUP_NAME VARCHAR(64) ,	
	PRIMARY KEY (PUBLISH_TAG)
);
CREATE TABLE CMS_PROJECTRESOURCES (
	PROJECT_ID INTEGER NOT NULL,
	RESOURCE_PATH VARCHAR(255) NOT NULL,
	PRIMARY KEY (PROJECT_ID, RESOURCE_PATH)

);
CREATE INDEX CMS_PROJECTRESOURCES_01_IDX
	ON CMS_PROJECTRESOURCES (RESOURCE_PATH);
CREATE TABLE CMS_BACKUP_PROJECTRESOURCES (
	PUBLISH_TAG INTEGER NOT NULL,
 	PROJECT_ID INTEGER NOT NULL,
	RESOURCE_PATH VARCHAR(255) NOT NULL,
	PRIMARY KEY (PUBLISH_TAG, PROJECT_ID, RESOURCE_PATH)
);
CREATE TABLE CMS_OFFLINE_PROPERTYDEF (
	PROPERTYDEF_ID VARCHAR(36)  NOT NULL, 
	PROPERTYDEF_NAME VARCHAR(128)  NOT NULL,
	PRIMARY KEY (PROPERTYDEF_ID)
);
CREATE UNIQUE INDEX iCMS_OFFLINE_PROPERTYDEF ON CMS_OFFLINE_PROPERTYDEF(PROPERTYDEF_NAME);
CREATE TABLE CMS_ONLINE_PROPERTYDEF (
	PROPERTYDEF_ID VARCHAR(36)  NOT NULL, 
	PROPERTYDEF_NAME VARCHAR(128)  NOT NULL,
	PRIMARY KEY (PROPERTYDEF_ID)	
);
CREATE TABLE CMS_BACKUP_PROPERTYDEF (
	PROPERTYDEF_ID VARCHAR(36)  NOT NULL, 
	PROPERTYDEF_NAME VARCHAR(128)  NOT NULL,
	PRIMARY KEY (PROPERTYDEF_ID)
);
CREATE UNIQUE INDEX iCMS_BACKUP_PROPERTYDEF ON CMS_BACKUP_PROPERTYDEF(PROPERTYDEF_NAME);
CREATE TABLE CMS_OFFLINE_PROPERTIES (
	PROPERTY_ID VARCHAR(36)  NOT NULL,
	PROPERTYDEF_ID VARCHAR(36)  NOT NULL,
	PROPERTY_MAPPING_ID VARCHAR(36)  NOT NULL,
	PROPERTY_MAPPING_TYPE INTEGER NOT NULL,
	PROPERTY_VALUE VARCHAR(2048) NOT NULL,
	PRIMARY KEY (PROPERTY_ID)
);
CREATE INDEX CMS_OFFLINE_PROPERTIES_01_IDX
	ON CMS_OFFLINE_PROPERTIES (PROPERTYDEF_ID);
CREATE INDEX CMS_OFFLINE_PROPERTIES_02_IDX
	ON CMS_OFFLINE_PROPERTIES (PROPERTY_MAPPING_ID);
CREATE INDEX CMS_OFFLINE_PROPERTIES_03_IDX
	ON CMS_OFFLINE_PROPERTIES (PROPERTYDEF_ID, PROPERTY_MAPPING_ID);
CREATE TABLE CMS_ONLINE_PROPERTIES (
	PROPERTY_ID VARCHAR(36)  NOT NULL,
	PROPERTYDEF_ID VARCHAR(36)  NOT NULL,
	PROPERTY_MAPPING_ID VARCHAR(36)  NOT NULL,
	PROPERTY_MAPPING_TYPE INTEGER NOT NULL,
	PROPERTY_VALUE VARCHAR(2048) NOT NULL,
	PRIMARY KEY(PROPERTY_ID)
);
CREATE INDEX CMS_ONLINE_PROPERTIES_01_IDX
	ON CMS_ONLINE_PROPERTIES (PROPERTYDEF_ID);
CREATE INDEX CMS_ONLINE_PROPERTIES_02_IDX
	ON CMS_ONLINE_PROPERTIES (PROPERTY_MAPPING_ID);
CREATE INDEX CMS_ONLINE_PROPERTIES_03_IDX
	ON CMS_ONLINE_PROPERTIES (PROPERTYDEF_ID, PROPERTY_MAPPING_ID);
CREATE TABLE CMS_BACKUP_PROPERTIES (
	BACKUP_ID VARCHAR(36)  NOT NULL,
	PROPERTY_ID VARCHAR(36)  NOT NULL,
	PROPERTYDEF_ID VARCHAR(36)  NOT NULL,
	PROPERTY_MAPPING_ID VARCHAR(36)  NOT NULL,
	PROPERTY_MAPPING_TYPE INTEGER NOT NULL,
	PROPERTY_VALUE VARCHAR(2048) NOT NULL,
	PUBLISH_TAG INTEGER,
	VERSION_ID INTEGER NOT NULL,
	PRIMARY KEY(PROPERTY_ID)
);
CREATE INDEX CMS_BACKUP_PROPERTIES_01_IDX
	ON CMS_BACKUP_PROPERTIES (PROPERTYDEF_ID);
CREATE INDEX CMS_BACKUP_PROPERTIES_02_IDX
	ON CMS_BACKUP_PROPERTIES (PROPERTY_MAPPING_ID);
CREATE INDEX CMS_BACKUP_PROPERTIES_03_IDX
	ON CMS_BACKUP_PROPERTIES (PROPERTYDEF_ID, PROPERTY_MAPPING_ID);
CREATE TABLE CMS_SYSTEMID (
	TABLE_KEY VARCHAR(255) NOT NULL,
	ID INTEGER NOT NULL,
	PRIMARY KEY(TABLE_KEY)
);
CREATE TABLE CMS_TASK (
	AUTOFINISH FIXED(11.0),
	ENDTIME TIMESTAMP,
	ESCALATIONTYPEREF FIXED(11.0),
	ID FIXED(11.0) NOT NULL,
	INITIATORUSERREF VARCHAR(36),
	MILESTONEREF FIXED(11.0),
	NAME VARCHAR(254),
	ORIGINALUSERREF VARCHAR(36),
	AGENTUSERREF VARCHAR(36),
	PARENT INTEGER,
	PERCENTAGE VARCHAR(50),
	PERMISSION VARCHAR(50),
	PRIORITYREF FIXED(11.0) DEFAULT '2',
	ROLEREF VARCHAR(36),
	ROOT FIXED(11.0),
	STARTTIME TIMESTAMP,
	STATE FIXED(11.0),
	TASKTYPEREF FIXED(11.0),
	TIMEOUT TIMESTAMP,
	WAKEUPTIME TIMESTAMP,
	HTMLLINK VARCHAR(254),
	ESTIMATETIME FIXED(11.0) DEFAULT '86400',
	PRIMARY KEY (ID)
);
CREATE TABLE CMS_TASKTYPE (
	AUTOFINISH FIXED(11.0),
	ESCALATIONTYPEREF FIXED(11.0),
	HTMLLINK VARCHAR(254),
	ID FIXED(11.0) NOT NULL,
	NAME VARCHAR(50),
	PERMISSION VARCHAR(50),
	PRIORITYREF FIXED(11.0),
	ROLEREF VARCHAR(36) ,
	PRIMARY KEY (ID)
);
CREATE TABLE CMS_TASKLOG (
	COMENT VARCHAR(2048),
	EXTERNALUSERNAME VARCHAR(254),
	ID FIXED(11.0) NOT NULL,
	STARTTIME TIMESTAMP,
	TASKREF FIXED(11.0),
	USERREF VARCHAR(36)  NOT NULL,
	TYPE FIXED(18.0) DEFAULT '0',
	PRIMARY KEY (ID)
);
CREATE TABLE CMS_TASKPAR (
	ID FIXED(11.0) NOT NULL ,
	PARNAME VARCHAR(50),
	PARVALUE VARCHAR(50),
	REF FIXED(11.0),
	PRIMARY KEY (ID)
);
CREATE TABLE CMS_ONLINE_ACCESSCONTROL (
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	PRINCIPAL_ID VARCHAR(36)  NOT NULL,
	ACCESS_ALLOWED INTEGER,
	ACCESS_DENIED INTEGER,
	ACCESS_FLAGS INTEGER,
	PRIMARY KEY (RESOURCE_ID, PRINCIPAL_ID)
);
CREATE TABLE CMS_OFFLINE_ACCESSCONTROL (
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	PRINCIPAL_ID VARCHAR(36)  NOT NULL,
	ACCESS_ALLOWED INTEGER,
	ACCESS_DENIED INTEGER,
	ACCESS_FLAGS INTEGER,
	PRIMARY KEY (RESOURCE_ID, PRINCIPAL_ID)
);
CREATE TABLE CMS_PUBLISH_HISTORY (
	HISTORY_ID VARCHAR(36)  NOT NULL,
	PUBLISH_TAG INTEGER NOT NULL,
	STRUCTURE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_PATH VARCHAR(1024) NOT NULL,
	RESOURCE_STATE INTEGER NOT NULL,
	RESOURCE_TYPE INTEGER NOT NULL,
	SIBLING_COUNT INTEGER NOT NULL,
	PRIMARY KEY (HISTORY_ID, PUBLISH_TAG, STRUCTURE_ID, RESOURCE_ID)
);
CREATE TABLE CMS_STATICEXPORT_LINKS (
	LINK_ID VARCHAR(36)  NOT NULL,
	LINK_RFS_PATH VARCHAR(1024) NOT NULL,
	LINK_TYPE INTEGER NOT NULL,
	LINK_PARAMETER VARCHAR(1024),
	LINK_TIMESTAMP FIXED(20,0),	
	PRIMARY KEY (LINK_ID)	
);
CREATE TABLE CMS_OFFLINE_STRUCTURE (
	STRUCTURE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	PARENT_ID VARCHAR(36)  NOT NULL,
	RESOURCE_PATH VARCHAR(255) NOT NULL,
	STRUCTURE_STATE INTEGER NOT NULL,
	DATE_RELEASED FIXED(20,0) NOT NULL,
	DATE_EXPIRED FIXED(20,0) NOT NULL,
	PRIMARY KEY (STRUCTURE_ID)
);
CREATE INDEX CMS_OFFLINE_STRUCTURE_01_IDX
	ON CMS_OFFLINE_STRUCTURE (STRUCTURE_ID, RESOURCE_PATH);
CREATE INDEX CMS_OFFLINE_STRUCTURE_02_IDX
	ON CMS_OFFLINE_STRUCTURE (RESOURCE_PATH, RESOURCE_ID);
CREATE INDEX CMS_OFFLINE_STRUCTURE_03_IDX
	ON CMS_OFFLINE_STRUCTURE (STRUCTURE_ID, RESOURCE_ID);
CREATE INDEX CMS_OFFLINE_STRUCTURE_04_IDX
	ON CMS_OFFLINE_STRUCTURE (STRUCTURE_STATE);
CREATE INDEX CMS_OFFLINE_STRUCTURE_05_IDX
	ON CMS_OFFLINE_STRUCTURE (PARENT_ID);
CREATE INDEX CMS_OFFLINE_STRUCTURE_06_IDX
	ON CMS_OFFLINE_STRUCTURE (RESOURCE_ID);
CREATE INDEX CMS_OFFLINE_STRUCTURE_07_IDX
	ON CMS_OFFLINE_STRUCTURE (RESOURCE_PATH);
CREATE TABLE CMS_ONLINE_STRUCTURE (
	STRUCTURE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	PARENT_ID VARCHAR(36)  NOT NULL,
	RESOURCE_PATH VARCHAR(255) NOT NULL,
	STRUCTURE_STATE INTEGER NOT NULL,
	DATE_RELEASED FIXED(20,0) NOT NULL,
	DATE_EXPIRED FIXED(20,0) NOT NULL,
	PRIMARY KEY (STRUCTURE_ID)
);
CREATE INDEX CMS_ONLINE_STRUCTURE_01_IDX
	ON CMS_ONLINE_STRUCTURE (STRUCTURE_ID, RESOURCE_PATH);
CREATE INDEX CMS_ONLINE_STRUCTURE_02_IDX
	ON CMS_ONLINE_STRUCTURE (RESOURCE_PATH, RESOURCE_ID);
CREATE INDEX CMS_ONLINE_STRUCTURE_03_IDX
	ON CMS_ONLINE_STRUCTURE (STRUCTURE_ID, RESOURCE_ID);
CREATE INDEX CMS_ONLINE_STRUCTURE_04_IDX
	ON CMS_ONLINE_STRUCTURE (STRUCTURE_STATE);
CREATE INDEX CMS_ONLINE_STRUCTURE_05_IDX
	ON CMS_ONLINE_STRUCTURE (PARENT_ID);
CREATE INDEX CMS_ONLINE_STRUCTURE_06_IDX
	ON CMS_ONLINE_STRUCTURE (RESOURCE_ID);
CREATE INDEX CMS_ONLINE_STRUCTURE_07_IDX
	ON CMS_ONLINE_STRUCTURE (RESOURCE_PATH);
CREATE TABLE CMS_BACKUP_STRUCTURE (
	BACKUP_ID VARCHAR(36)  NOT NULL,
	PUBLISH_TAG INTEGER NOT NULL,
	VERSION_ID INTEGER NOT NULL,
	STRUCTURE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_PATH VARCHAR(255) NOT NULL,
	STRUCTURE_STATE INTEGER NOT NULL,
	DATE_RELEASED FIXED(20,0) NOT NULL,
	DATE_EXPIRED FIXED(20,0) NOT NULL,
	PRIMARY KEY (BACKUP_ID)
);
CREATE INDEX CMS_BACKUP_STRUCTURE_01_IDX
	ON CMS_BACKUP_STRUCTURE (STRUCTURE_ID, RESOURCE_PATH);
CREATE INDEX CMS_BACKUP_STRUCTURE_02_IDX
	ON CMS_BACKUP_STRUCTURE (RESOURCE_PATH, RESOURCE_ID);
CREATE INDEX CMS_BACKUPE_STRUCTURE_03_IDX
	ON CMS_BACKUP_STRUCTURE (STRUCTURE_ID, RESOURCE_ID);
CREATE INDEX CMS_BACKUP_STRUCTURE_04_IDX
	ON CMS_BACKUP_STRUCTURE (STRUCTURE_STATE);
CREATE INDEX CMS_BACKUP_STRUCTURE_05_IDX
	ON CMS_BACKUP_STRUCTURE (RESOURCE_ID);
CREATE INDEX CMS_BACKUP_STRUCTURE_07_IDX
	ON CMS_BACKUP_STRUCTURE (RESOURCE_PATH);
CREATE TABLE CMS_OFFLINE_RESOURCES (
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_TYPE INTEGER NOT NULL,
	RESOURCE_FLAGS INTEGER NOT NULL,
	RESOURCE_STATE	INTEGER NOT NULL,
	RESOURCE_SIZE INTEGER NOT NULL,                                         
	SIBLING_COUNT INTEGER NOT NULL,
	DATE_CREATED FIXED(20,0) NOT NULL,
	DATE_LASTMODIFIED FIXED(20,0) NOT NULL,
	USER_CREATED VARCHAR(36)  NOT NULL,                                         
	USER_LASTMODIFIED VARCHAR(36)  NOT NULL,
	PROJECT_LASTMODIFIED INTEGER NOT NULL,          
	PRIMARY KEY(RESOURCE_ID)
);
CREATE INDEX CMS_OFFLINE_RESOURCES_01_IDX
	ON CMS_OFFLINE_RESOURCES (PROJECT_LASTMODIFIED);
CREATE INDEX CMS_OFFLINE_RESOURCES_02_IDX
	ON CMS_OFFLINE_RESOURCES (PROJECT_LASTMODIFIED, RESOURCE_SIZE);
CREATE INDEX CMS_OFFLINE_RESOURCES_03_IDX
	ON CMS_OFFLINE_RESOURCES (RESOURCE_SIZE);
CREATE INDEX CMS_OFFLINE_RESOURCES_04_IDX
	ON CMS_OFFLINE_RESOURCES (DATE_LASTMODIFIED);
CREATE INDEX CMS_OFFLINE_RESOURCES_05_IDX
	ON CMS_OFFLINE_RESOURCES (RESOURCE_TYPE);
CREATE TABLE CMS_ONLINE_RESOURCES (
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_TYPE INTEGER NOT NULL,
	RESOURCE_FLAGS INTEGER NOT NULL,
	RESOURCE_STATE	INTEGER NOT NULL,
	RESOURCE_SIZE INTEGER NOT NULL,
	SIBLING_COUNT INTEGER NOT NULL,	
	DATE_CREATED FIXED(20,0) NOT NULL,
	DATE_LASTMODIFIED FIXED(20,0) NOT NULL,
	USER_CREATED VARCHAR(36)  NOT NULL,                                         
	USER_LASTMODIFIED VARCHAR(36)  NOT NULL,
	PROJECT_LASTMODIFIED INTEGER NOT NULL,
	PRIMARY KEY(RESOURCE_ID)
);
CREATE INDEX CMS_ONLINE_RESOURCES_01_IDX
	ON CMS_ONLINE_RESOURCES (PROJECT_LASTMODIFIED);
CREATE INDEX CMS_ONLINE_RESOURCES_02_IDX
	ON CMS_ONLINE_RESOURCES (PROJECT_LASTMODIFIED, RESOURCE_SIZE);
CREATE INDEX CMS_ONLINE_RESOURCES_03_IDX
	ON CMS_ONLINE_RESOURCES (RESOURCE_SIZE);
CREATE INDEX CMS_ONLINE_RESOURCES_04_IDX
	ON CMS_ONLINE_RESOURCES (DATE_LASTMODIFIED);
CREATE INDEX CMS_ONLINE_RESOURCES_05_IDX
	ON CMS_ONLINE_RESOURCES (RESOURCE_TYPE);
CREATE TABLE CMS_BACKUP_RESOURCES (
	BACKUP_ID VARCHAR(36)  NOT NULL,
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	RESOURCE_TYPE INTEGER NOT NULL,
	RESOURCE_FLAGS INTEGER NOT NULL,
	RESOURCE_STATE	INTEGER NOT NULL,
	RESOURCE_SIZE INTEGER NOT NULL,
	SIBLING_COUNT INTEGER NOT NULL,	
	DATE_CREATED FIXED(20,0) NOT NULL,
	DATE_LASTMODIFIED FIXED(20,0) NOT NULL,
	USER_CREATED VARCHAR(36)  NOT NULL,
	USER_LASTMODIFIED VARCHAR(36)  NOT NULL,
	PROJECT_LASTMODIFIED INTEGER NOT NULL,
	PUBLISH_TAG INTEGER NOT NULL,
	VERSION_ID INTEGER NOT NULL,
	USER_CREATED_NAME VARCHAR(64) NOT NULL,
	USER_LASTMODIFIED_NAME VARCHAR(64) NOT NULL,
	PRIMARY KEY(BACKUP_ID)
);
CREATE INDEX CMS_BACKUP_RESOURCES_01_IDX
	ON CMS_BACKUP_RESOURCES (PROJECT_LASTMODIFIED);
CREATE INDEX CMS_BACKUP_RESOURCES_02_IDX
	ON CMS_BACKUP_RESOURCES (PROJECT_LASTMODIFIED, RESOURCE_SIZE);
CREATE INDEX CMS_BACKUP_RESOURCES_03_IDX
	ON CMS_BACKUP_RESOURCES (RESOURCE_SIZE);
CREATE INDEX CMS_BACKUP_RESOURCES_04_IDX
	ON CMS_BACKUP_RESOURCES (DATE_LASTMODIFIED);
CREATE INDEX CMS_BACKUP_RESOURCES_05_IDX
	ON CMS_BACKUP_RESOURCES (RESOURCE_TYPE);
CREATE TABLE CMS_OFFLINE_CONTENTS (
	CONTENT_ID VARCHAR(36)  NOT NULL,
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	FILE_CONTENT LONG BYTE NOT NULL,
	PRIMARY KEY(CONTENT_ID)
);
CREATE TABLE CMS_ONLINE_CONTENTS (
	CONTENT_ID VARCHAR(36)  NOT NULL,
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	FILE_CONTENT LONG BYTE NOT NULL,
	PRIMARY KEY(CONTENT_ID)
);
CREATE TABLE CMS_BACKUP_CONTENTS (
	BACKUP_ID VARCHAR(36)  NOT NULL,
	CONTENT_ID VARCHAR(36)  NOT NULL,
	RESOURCE_ID VARCHAR(36)  NOT NULL,
	FILE_CONTENT LONG BYTE NOT NULL,
	PUBLISH_TAG INTEGER,
	VERSION_ID INTEGER NOT NULL,
	PRIMARY KEY(BACKUP_ID)
);
CREATE INDEX CMS_BACKUP_CONTENTS_01_IDX
	ON CMS_BACKUP_CONTENTS (RESOURCE_ID);


    
